yt.analysis_modules.halo_finding.halo_objects.RockstarHalo.rms_velocity — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.RockstarHalo.rms_velocity

`RockstarHalo.` `rms_velocity`(*args, **kwargs)

  Returns the mass-weighted RMS velocity for the halo particles in cgs units.

  Calculate and return the mass-weighted RMS velocity for just the particles in the halo. The bulk velocity of the halo is subtracted before computation.

  Examples

      >>> rms_vel = halos[0].rms_velocity()